==> haskell-ormolu-0.3.0.0-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ormolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ormolu
version:              0.3.0.0
visibility:           public
id:                   ormolu-0.3.0.0-ERz2DZ09cs4CsIExHOWrHz
key:                  ormolu-0.3.0.0-ERz2DZ09cs4CsIExHOWrHz
license:              BSD-3-Clause
maintainer:           Mark Karpov <mark.karpov@tweag.io>
homepage:             https://github.com/tweag/ormolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  259cf95e3f8e74fd82c4216e5942f8a9
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Imports Ormolu.Parser Ormolu.Parser.Anns
    Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Extensions Ormolu.Utils.IO

hidden-modules:       GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ormolu-0.3.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ormolu-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ormolu
hs-libraries:         HSormolu-0.3.0.0-ERz2DZ09cs4CsIExHOWrHz
depends:
    Cabal-3.4.1.0 Diff-0.4.1-4cFSoUDI9sIHfLU08LSG2N
    ansi-terminal-0.11.4-2iacZJf8S6H9mYjywRyHYf base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    dlist-1.0-DsmLszrk0d78USIO4E29oj exceptions-0.10.4 filepath-1.4.2.1
    ghc-9.0.2 ghc-boot-9.0.2 ghc-boot-th-9.0.2 mtl-2.2.2
    syb-0.7.2.2-7nm2PnLG8s1xlFdgRPgpe text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-ormolu/html/ormolu.haddock
haddock-html:         /usr/share/doc/haskell-ormolu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ormolu-0.3.0.0-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ormolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ormolu
version:              0.3.0.0
visibility:           public
id:                   ormolu-0.3.0.0-FZyknEuasqHExaDux3NFIk
key:                  ormolu-0.3.0.0-FZyknEuasqHExaDux3NFIk
license:              BSD-3-Clause
maintainer:           Mark Karpov <mark.karpov@tweag.io>
homepage:             https://github.com/tweag/ormolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  7317df27cac595a407561f223c238bf3
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Imports Ormolu.Parser Ormolu.Parser.Anns
    Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Extensions Ormolu.Utils.IO

hidden-modules:       GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.0.2/site-local/ormolu-0.3.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/ormolu-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ormolu
hs-libraries:         HSormolu-0.3.0.0-FZyknEuasqHExaDux3NFIk
depends:
    Cabal-3.4.1.0 Diff-0.4.1-1IO8RfSzzW83e8uI1umwz8
    ansi-terminal-0.11.4-30w7KBHfEQ9CygddjSQvBk base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1 directory-1.3.6.2
    dlist-1.0-JalAZsGq1LOCqqdFHHEpoL exceptions-0.10.4 filepath-1.4.2.1
    ghc-9.0.2 ghc-boot-9.0.2 ghc-boot-th-9.0.2 mtl-2.2.2
    syb-0.7.2.3-F4C6wO1lPr57dhtwlEni6j text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-ormolu/html/ormolu.haddock
haddock-html:         /usr/share/doc/haskell-ormolu/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
